@@ -40,6 +40,7 @@ import os
 from datetime import datetime, timedelta
 
 from airflow import models
+from airflow.models.baseoperator import chain
 from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import (
     ALREADY_EXISTING_IN_SINK,
     AWS_S3_DATA_SOURCE,
@@ -72,7 +73,6 @@ from airflow.providers.google.cloud.operators.cloud_storage_transfer_service imp
 from airflow.providers.google.cloud.sensors.cloud_storage_transfer_service import (
     CloudDataTransferServiceJobStatusSensor,
 )
-from airflow.utils.dates import days_ago
 
 GCP_PROJECT_ID = os.environ.get('GCP_PROJECT_ID', 'example-project')
 GCP_DESCRIPTION = os.environ.get('GCP_DESCRIPTION', 'description')
@@ -109,7 +109,8 @@ aws_to_gcs_transfer_body = {
 with models.DAG(
     'example_gcp_transfer_aws',
     schedule_interval=None,  # Override to match your needs
-    start_date=days_ago(1),
+    start_date=datetime(2021, 1, 1),
+    catchup=False,
     tags=['example'],
 ) as dag:
 
@@ -183,8 +184,14 @@ with models.DAG(
     )
     # [END howto_operator_gcp_transfer_delete_job]
 
-    # fmt: off
-    create_transfer_job_from_aws >> wait_for_operation_to_start >> pause_operation
-    pause_operation >> list_operations >> get_operation >> resume_operation
-    resume_operation >> wait_for_operation_to_end >> cancel_operation >> delete_transfer_from_aws_job
-    # fmt: on
+    chain(
+        create_transfer_job_from_aws,
+        wait_for_operation_to_start,
+        pause_operation,
+        list_operations,
+        get_operation,
+        resume_operation,
+        wait_for_operation_to_end,
+        cancel_operation,
+        delete_transfer_from_aws_job,
+    )
