@@ -26,7 +26,7 @@ from google.cloud.devtools.cloudbuild import CloudBuildClient
 from google.cloud.devtools.cloudbuild_v1.types import Build, BuildTrigger, RepoSource
 
 from airflow.exceptions import AirflowException
-from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
 # Time to sleep between active checks of the operation results
 TIME_TO_SLEEP_IN_SECONDS = 5
@@ -95,10 +95,10 @@ class CloudBuildHook(GoogleBaseHook):
     def cancel_build(
         self,
         id_: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> Build:
         """
         Cancels a build in progress.
@@ -124,9 +124,11 @@ class CloudBuildHook(GoogleBaseHook):
         self.log.info("Start cancelling build: %s.", id_)
 
         build = client.cancel_build(
-            request={'project_id': project_id, 'id': id_}, retry=retry, timeout=timeout, metadata=metadata
+            request={'project_id': project_id, 'id': id_},
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
-
         self.log.info("Build has been cancelled: %s.", id_)
 
         return build
@@ -135,11 +137,11 @@ class CloudBuildHook(GoogleBaseHook):
     def create_build(
         self,
         build: Union[Dict, Build],
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         wait: bool = True,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> Build:
         """
         Starts a build with the specified configuration.
@@ -189,10 +191,10 @@ class CloudBuildHook(GoogleBaseHook):
     def create_build_trigger(
         self,
         trigger: Union[dict, BuildTrigger],
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> BuildTrigger:
         """
         Creates a new BuildTrigger.
@@ -233,10 +235,10 @@ class CloudBuildHook(GoogleBaseHook):
     def delete_build_trigger(
         self,
         trigger_id: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         Deletes a BuildTrigger by its project ID and trigger ID.
@@ -272,10 +274,10 @@ class CloudBuildHook(GoogleBaseHook):
     def get_build(
         self,
         id_: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> Build:
         """
         Returns information about a previously requested build.
@@ -301,7 +303,10 @@ class CloudBuildHook(GoogleBaseHook):
         self.log.info("Start retrieving build: %s.", id_)
 
         build = client.get_build(
-            request={'project_id': project_id, 'id': id_}, retry=retry, timeout=timeout, metadata=metadata
+            request={'project_id': project_id, 'id': id_},
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
         self.log.info("Build has been retrieved: %s.", id_)
@@ -312,10 +317,10 @@ class CloudBuildHook(GoogleBaseHook):
     def get_build_trigger(
         self,
         trigger_id: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> BuildTrigger:
         """
         Returns information about a BuildTrigger.
@@ -354,13 +359,13 @@ class CloudBuildHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def list_build_triggers(
         self,
-        project_id: str,
         location: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         page_size: Optional[int] = None,
         page_token: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> List[BuildTrigger]:
         """
         Lists existing BuildTriggers.
@@ -410,14 +415,14 @@ class CloudBuildHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def list_builds(
         self,
-        project_id: str,
         location: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         page_size: Optional[int] = None,
         page_token: Optional[int] = None,
         filter_: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> List[Build]:
         """
         Lists previously requested builds.
@@ -471,11 +476,11 @@ class CloudBuildHook(GoogleBaseHook):
     def retry_build(
         self,
         id_: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         wait: bool = True,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> Build:
         """
         Creates a new build based on the specified build. This method creates a new build
@@ -504,7 +509,10 @@ class CloudBuildHook(GoogleBaseHook):
         self.log.info("Start retrying build: %s.", id_)
 
         operation = client.retry_build(
-            request={'project_id': project_id, 'id': id_}, retry=retry, timeout=timeout, metadata=metadata
+            request={'project_id': project_id, 'id': id_},
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
         id_ = self._get_build_id_from_operation(Operation)
@@ -523,11 +531,11 @@ class CloudBuildHook(GoogleBaseHook):
         self,
         trigger_id: str,
         source: Union[dict, RepoSource],
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         wait: bool = True,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> Build:
         """
         Runs a BuildTrigger at a particular source revision.
@@ -583,7 +591,7 @@ class CloudBuildHook(GoogleBaseHook):
         project_id: str,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> BuildTrigger:
         """
         Updates a BuildTrigger by its project ID and trigger ID.
