@@ -15,16 +15,18 @@
 # specific language governing permissions and limitations
 # under the License.
 import shlex
+import sys
 import time
 from io import StringIO
 from typing import Any, Dict, Optional
 
 import paramiko
 
-try:
+if sys.version_info >= (3, 8):
     from functools import cached_property
-except ImportError:
+else:
     from cached_property import cached_property
+
 from google.api_core.retry import exponential_sleep_generator
 
 from airflow import AirflowException
@@ -95,7 +97,7 @@ class ComputeEngineSSHHook(SSHHook):
     """
 
     conn_name_attr = 'gcp_conn_id'
-    default_conn_name = 'google_cloud_default'
+    default_conn_name = 'google_cloud_ssh_default'
     conn_type = 'gcpssh'
     hook_name = 'Google Cloud SSH'
 
