@@ -19,16 +19,17 @@
 """This module contains Google Cloud Stackdriver operators."""
 
 import json
-from typing import Any, Optional, Sequence, Union
+from typing import Any, Optional, Sequence, Tuple, Union
 
 from google.api_core.exceptions import InvalidArgument
 from google.api_core.gapic_v1.method import DEFAULT
 from google.cloud import monitoring_v3
-from google.protobuf.json_format import MessageToDict, MessageToJson, Parse
+from google.cloud.monitoring_v3 import AlertPolicy, NotificationChannel
+from google.protobuf.field_mask_pb2 import FieldMask
 from googleapiclient.errors import HttpError
 
 from airflow.exceptions import AirflowException
-from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
 
 class StackdriverHook(GoogleBaseHook):
@@ -61,14 +62,14 @@ class StackdriverHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def list_alert_policies(
         self,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         format_: Optional[str] = None,
         filter_: Optional[str] = None,
         order_by: Optional[str] = None,
         page_size: Optional[int] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> Any:
         """
         Fetches all the Alert Policies identified by the filter passed as
@@ -110,18 +111,20 @@ class StackdriverHook(GoogleBaseHook):
         """
         client = self._get_policy_client()
         policies_ = client.list_alert_policies(
-            name=f'projects/{project_id}',
-            filter_=filter_,
-            order_by=order_by,
-            page_size=page_size,
+            request={
+                'name': f'projects/{project_id}',
+                'filter': filter_,
+                'order_by': order_by,
+                'page_size': page_size,
+            },
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
         if format_ == "dict":
-            return [MessageToDict(policy) for policy in policies_]
+            return [AlertPolicy.to_dict(policy) for policy in policies_]
         elif format_ == "json":
-            return [MessageToJson(policy) for policy in policies_]
+            return [AlertPolicy.to_jsoon(policy) for policy in policies_]
         else:
             return policies_
 
@@ -129,31 +132,33 @@ class StackdriverHook(GoogleBaseHook):
     def _toggle_policy_status(
         self,
         new_state: bool,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ):
         client = self._get_policy_client()
         policies_ = self.list_alert_policies(project_id=project_id, filter_=filter_)
         for policy in policies_:
-            if policy.enabled.value != bool(new_state):
-                policy.enabled.value = bool(new_state)
-                mask = monitoring_v3.types.field_mask_pb2.FieldMask()
-                mask.paths.append('enabled')  # pylint: disable=no-member
+            if policy.enabled != bool(new_state):
+                policy.enabled = bool(new_state)
+                mask = FieldMask(paths=['enabled'])
                 client.update_alert_policy(
-                    alert_policy=policy, update_mask=mask, retry=retry, timeout=timeout, metadata=metadata
+                    request={'alert_policy': policy, 'update_mask': mask},
+                    retry=retry,
+                    timeout=timeout,
+                    metadata=metadata,
                 )
 
     @GoogleBaseHook.fallback_to_default_project_id
     def enable_alert_policies(
         self,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         Enables one or more disabled alerting policies identified by filter
@@ -187,11 +192,11 @@ class StackdriverHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def disable_alert_policies(
         self,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         Disables one or more enabled alerting policies identified by filter
@@ -226,10 +231,10 @@ class StackdriverHook(GoogleBaseHook):
     def upsert_alert(
         self,
         alerts: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
          Creates a new alert or updates an existing policy identified
@@ -265,31 +270,30 @@ class StackdriverHook(GoogleBaseHook):
         ]
         policies_ = []
         channels = []
-
-        for channel in record["channels"]:
-            channel_json = json.dumps(channel)
-            channels.append(Parse(channel_json, monitoring_v3.types.notification_pb2.NotificationChannel()))
-        for policy in record["policies"]:
-            policy_json = json.dumps(policy)
-            policies_.append(Parse(policy_json, monitoring_v3.types.alert_pb2.AlertPolicy()))
+        for channel in record.get("channels", []):
+            channels.append(NotificationChannel(**channel))
+        for policy in record.get("policies", []):
+            policies_.append(AlertPolicy(**policy))
 
         channel_name_map = {}
 
         for channel in channels:
             channel.verification_status = (
-                monitoring_v3.enums.NotificationChannel.VerificationStatus.VERIFICATION_STATUS_UNSPECIFIED
+                monitoring_v3.NotificationChannel.VerificationStatus.VERIFICATION_STATUS_UNSPECIFIED
             )
 
             if channel.name in existing_channels:
                 channel_client.update_notification_channel(
-                    notification_channel=channel, retry=retry, timeout=timeout, metadata=metadata
+                    request={'notification_channel': channel},
+                    retry=retry,
+                    timeout=timeout,
+                    metadata=metadata,
                 )
             else:
                 old_name = channel.name
-                channel.ClearField('name')
+                channel.name = None
                 new_channel = channel_client.create_notification_channel(
-                    name=f'projects/{project_id}',
-                    notification_channel=channel,
+                    request={'name': f'projects/{project_id}', 'notification_channel': channel},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -297,8 +301,8 @@ class StackdriverHook(GoogleBaseHook):
                 channel_name_map[old_name] = new_channel.name
 
         for policy in policies_:
-            policy.ClearField('creation_record')
-            policy.ClearField('mutation_record')
+            policy.creation_record = None
+            policy.mutation_record = None
 
             for i, channel in enumerate(policy.notification_channels):
                 new_channel = channel_name_map.get(channel)
@@ -308,28 +312,30 @@ class StackdriverHook(GoogleBaseHook):
             if policy.name in existing_policies:
                 try:
                     policy_client.update_alert_policy(
-                        alert_policy=policy, retry=retry, timeout=timeout, metadata=metadata
+                        request={'alert_policy': policy},
+                        retry=retry,
+                        timeout=timeout,
+                        metadata=metadata,
                     )
                 except InvalidArgument:
                     pass
             else:
-                policy.ClearField('name')
+                policy.name = None
                 for condition in policy.conditions:
-                    condition.ClearField('name')
+                    condition.name = None
                 policy_client.create_alert_policy(
-                    name=f'projects/{project_id}',
-                    alert_policy=policy,
+                    request={'name': f'projects/{project_id}', 'alert_policy': policy},
                     retry=retry,
                     timeout=timeout,
-                    metadata=None,
+                    metadata=metadata,
                 )
 
     def delete_alert_policy(
         self,
         name: str,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         Deletes an alerting policy.
@@ -349,21 +355,23 @@ class StackdriverHook(GoogleBaseHook):
         """
         policy_client = self._get_policy_client()
         try:
-            policy_client.delete_alert_policy(name=name, retry=retry, timeout=timeout, metadata=metadata)
+            policy_client.delete_alert_policy(
+                request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+            )
         except HttpError as err:
             raise AirflowException(f'Delete alerting policy failed. Error was {err.content}')
 
     @GoogleBaseHook.fallback_to_default_project_id
     def list_notification_channels(
         self,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         format_: Optional[str] = None,
         filter_: Optional[str] = None,
         order_by: Optional[str] = None,
         page_size: Optional[int] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[str] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> Any:
         """
         Fetches all the Notification Channels identified by the filter passed as
@@ -405,18 +413,20 @@ class StackdriverHook(GoogleBaseHook):
         """
         client = self._get_channel_client()
         channels = client.list_notification_channels(
-            name=f'projects/{project_id}',
-            filter_=filter_,
-            order_by=order_by,
-            page_size=page_size,
+            request={
+                'name': f'projects/{project_id}',
+                'filter': filter_,
+                'order_by': order_by,
+                'page_size': page_size,
+            },
             retry=retry,
             timeout=timeout,
             metadata=metadata,
         )
         if format_ == "dict":
-            return [MessageToDict(channel) for channel in channels]
+            return [NotificationChannel.to_dict(channel) for channel in channels]
         elif format_ == "json":
-            return [MessageToJson(channel) for channel in channels]
+            return [NotificationChannel.to_json(channel) for channel in channels]
         else:
             return channels
 
@@ -424,22 +434,22 @@ class StackdriverHook(GoogleBaseHook):
     def _toggle_channel_status(
         self,
         new_state: bool,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[str] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         client = self._get_channel_client()
-        channels = client.list_notification_channels(name=f'projects/{project_id}', filter_=filter_)
+        channels = client.list_notification_channels(
+            request={'name': f'projects/{project_id}', 'filter': filter_}
+        )
         for channel in channels:
-            if channel.enabled.value != bool(new_state):
-                channel.enabled.value = bool(new_state)
-                mask = monitoring_v3.types.field_mask_pb2.FieldMask()
-                mask.paths.append('enabled')  # pylint: disable=no-member
+            if channel.enabled != bool(new_state):
+                channel.enabled = bool(new_state)
+                mask = FieldMask(paths=['enabled'])
                 client.update_notification_channel(
-                    notification_channel=channel,
-                    update_mask=mask,
+                    request={'notification_channel': channel, 'update_mask': mask},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -448,11 +458,11 @@ class StackdriverHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def enable_notification_channels(
         self,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[str] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         Enables one or more disabled alerting policies identified by filter
@@ -489,8 +499,8 @@ class StackdriverHook(GoogleBaseHook):
         project_id: str,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[str] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         Disables one or more enabled notification channels identified by filter
@@ -527,8 +537,8 @@ class StackdriverHook(GoogleBaseHook):
         channels: str,
         project_id: str,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> dict:
         """
         Creates a new notification or updates an existing notification channel
@@ -562,26 +572,25 @@ class StackdriverHook(GoogleBaseHook):
         channel_name_map = {}
 
         for channel in record["channels"]:
-            channel_json = json.dumps(channel)
-            channels_list.append(
-                Parse(channel_json, monitoring_v3.types.notification_pb2.NotificationChannel())
-            )
+            channels_list.append(NotificationChannel(**channel))
 
         for channel in channels_list:
             channel.verification_status = (
-                monitoring_v3.enums.NotificationChannel.VerificationStatus.VERIFICATION_STATUS_UNSPECIFIED
+                monitoring_v3.NotificationChannel.VerificationStatus.VERIFICATION_STATUS_UNSPECIFIED
             )
 
             if channel.name in existing_channels:
                 channel_client.update_notification_channel(
-                    notification_channel=channel, retry=retry, timeout=timeout, metadata=metadata
+                    request={'notification_channel': channel},
+                    retry=retry,
+                    timeout=timeout,
+                    metadata=metadata,
                 )
             else:
                 old_name = channel.name
-                channel.ClearField('name')
+                channel.name = None
                 new_channel = channel_client.create_notification_channel(
-                    name=f'projects/{project_id}',
-                    notification_channel=channel,
+                    request={'name': f'projects/{project_id}', 'notification_channel': channel},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -594,8 +603,8 @@ class StackdriverHook(GoogleBaseHook):
         self,
         name: str,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[str] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         Deletes a notification channel.
@@ -616,7 +625,7 @@ class StackdriverHook(GoogleBaseHook):
         channel_client = self._get_channel_client()
         try:
             channel_client.delete_notification_channel(
-                name=name, retry=retry, timeout=timeout, metadata=metadata
+                request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
             )
         except HttpError as err:
             raise AirflowException(f'Delete notification channel failed. Error was {err.content}')
