@@ -16,11 +16,15 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Vision Hook."""
-
+import sys
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 
-from cached_property import cached_property
+if sys.version_info >= (3, 8):
+    from functools import cached_property
+else:
+    from cached_property import cached_property
+
 from google.api_core.retry import Retry
 from google.cloud.vision_v1 import ImageAnnotatorClient, ProductSearchClient
 from google.cloud.vision_v1.types import (
@@ -34,7 +38,7 @@ from google.cloud.vision_v1.types import (
 from google.protobuf.json_format import MessageToDict
 
 from airflow.exceptions import AirflowException
-from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
 ERR_DIFF_NAMES = """The {label} name provided in the object ({explicit_name}) is different
     than the name created from the input parameters ({constructed_name}). Please either:
@@ -171,11 +175,11 @@ class CloudVisionHook(GoogleBaseHook):
         self,
         location: str,
         product_set: Union[dict, ProductSet],
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         product_set_id: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> str:
         """
         For the documentation see:
@@ -207,10 +211,10 @@ class CloudVisionHook(GoogleBaseHook):
         self,
         location: str,
         product_set_id: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> dict:
         """
         For the documentation see:
@@ -228,13 +232,13 @@ class CloudVisionHook(GoogleBaseHook):
     def update_product_set(
         self,
         product_set: Union[dict, ProductSet],
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         location: Optional[str] = None,
         product_set_id: Optional[str] = None,
         update_mask: Union[dict, FieldMask] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> dict:
         """
         For the documentation see:
@@ -257,10 +261,10 @@ class CloudVisionHook(GoogleBaseHook):
         self,
         location: str,
         product_set_id: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         For the documentation see:
@@ -277,11 +281,11 @@ class CloudVisionHook(GoogleBaseHook):
         self,
         location: str,
         product: Union[dict, Product],
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         product_id: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ):
         """
         For the documentation see:
@@ -313,10 +317,10 @@ class CloudVisionHook(GoogleBaseHook):
         self,
         location: str,
         product_id: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ):
         """
         For the documentation see:
@@ -334,13 +338,13 @@ class CloudVisionHook(GoogleBaseHook):
     def update_product(
         self,
         product: Union[dict, Product],
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         location: Optional[str] = None,
         product_id: Optional[str] = None,
         update_mask: Optional[Dict[str, FieldMask]] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ):
         """
         For the documentation see:
@@ -361,10 +365,10 @@ class CloudVisionHook(GoogleBaseHook):
         self,
         location: str,
         product_id: str,
-        project_id: str,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         For the documentation see:
@@ -386,7 +390,7 @@ class CloudVisionHook(GoogleBaseHook):
         reference_image_id: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> str:
         """
         For the documentation see:
@@ -426,7 +430,7 @@ class CloudVisionHook(GoogleBaseHook):
         project_id: str,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> dict:
         """
         For the documentation see:
@@ -437,7 +441,7 @@ class CloudVisionHook(GoogleBaseHook):
         name = ProductSearchClient.reference_image_path(
             project=project_id, location=location, product=product_id, reference_image=reference_image_id
         )
-        # pylint: disable=assignment-from-no-return
+
         response = client.delete_reference_image(
             name=name,
             retry=retry,
@@ -457,7 +461,7 @@ class CloudVisionHook(GoogleBaseHook):
         location: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         For the documentation see:
@@ -485,11 +489,11 @@ class CloudVisionHook(GoogleBaseHook):
         location: Optional[str] = None,
         retry: Optional[Retry] = None,
         timeout: Optional[float] = None,
-        metadata: Optional[Sequence[Tuple[str, str]]] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         """
         For the documentation see:
-        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionRemoveProductFromProductSetOperator` # pylint: disable=line-too-long # noqa
+        :py:class:`~airflow.providers.google.cloud.operators.vision.CloudVisionRemoveProductFromProductSetOperator`
         """
         client = self.get_conn()
 
@@ -518,7 +522,6 @@ class CloudVisionHook(GoogleBaseHook):
 
         self.log.info('Annotating image')
 
-        # pylint: disable=no-member
         response = client.annotate_image(request=request, retry=retry, timeout=timeout)
 
         self.log.info('Image annotated')
@@ -540,9 +543,7 @@ class CloudVisionHook(GoogleBaseHook):
 
         self.log.info('Annotating images')
 
-        response = client.batch_annotate_images(
-            requests=requests, retry=retry, timeout=timeout  # pylint: disable=no-member
-        )
+        response = client.batch_annotate_images(requests=requests, retry=retry, timeout=timeout)
 
         self.log.info('Images annotated')
 
@@ -568,7 +569,7 @@ class CloudVisionHook(GoogleBaseHook):
         if additional_properties is None:
             additional_properties = {}
 
-        response = client.text_detection(  # pylint: disable=no-member
+        response = client.text_detection(
             image=image, max_results=max_results, retry=retry, timeout=timeout, **additional_properties
         )
         response = MessageToDict(response)
@@ -598,7 +599,7 @@ class CloudVisionHook(GoogleBaseHook):
         if additional_properties is None:
             additional_properties = {}
 
-        response = client.document_text_detection(  # pylint: disable=no-member
+        response = client.document_text_detection(
             image=image, max_results=max_results, retry=retry, timeout=timeout, **additional_properties
         )
         response = MessageToDict(response)
@@ -628,7 +629,7 @@ class CloudVisionHook(GoogleBaseHook):
         if additional_properties is None:
             additional_properties = {}
 
-        response = client.label_detection(  # pylint: disable=no-member
+        response = client.label_detection(
             image=image, max_results=max_results, retry=retry, timeout=timeout, **additional_properties
         )
         response = MessageToDict(response)
@@ -658,7 +659,7 @@ class CloudVisionHook(GoogleBaseHook):
         if additional_properties is None:
             additional_properties = {}
 
-        response = client.safe_search_detection(  # pylint: disable=no-member
+        response = client.safe_search_detection(
             image=image, max_results=max_results, retry=retry, timeout=timeout, **additional_properties
         )
         response = MessageToDict(response)
