@@ -17,7 +17,7 @@
 # under the License.
 """This module contains Google Cloud Bigtable operators."""
 import enum
-from typing import Dict, Iterable, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Dict, Iterable, List, Optional, Sequence, Union
 
 import google.api_core.exceptions
 from google.cloud.bigtable.column_family import GarbageCollectionRule
@@ -27,6 +27,9 @@ from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigtable import BigtableHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class BigtableValidationMixin:
     """Common class for Cloud Bigtable operators for validating required fields."""
@@ -101,13 +104,13 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
     """
 
     REQUIRED_ATTRIBUTES: Iterable[str] = ('instance_id', 'main_cluster_id', 'main_cluster_zone')
-    template_fields: Iterable[str] = [
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'main_cluster_id',
         'main_cluster_zone',
         'impersonation_chain',
-    ]
+    )
 
     def __init__(
         self,
@@ -147,7 +150,7 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -222,11 +225,11 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
     """
 
     REQUIRED_ATTRIBUTES: Iterable[str] = ['instance_id']
-    template_fields: Iterable[str] = [
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'impersonation_chain',
-    ]
+    )
 
     def __init__(
         self,
@@ -252,7 +255,7 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -305,11 +308,11 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
     """
 
     REQUIRED_ATTRIBUTES = ('instance_id',)  # type: Iterable[str]
-    template_fields = [
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'impersonation_chain',
-    ]  # type: Iterable[str]
+    )
 
     def __init__(
         self,
@@ -327,7 +330,7 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -385,12 +388,12 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
     """
 
     REQUIRED_ATTRIBUTES = ('instance_id', 'table_id')  # type: Iterable[str]
-    template_fields = [
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'table_id',
         'impersonation_chain',
-    ]  # type: Iterable[str]
+    )
 
     def __init__(
         self,
@@ -435,7 +438,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
                 return False
         return True
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -494,12 +497,12 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
     """
 
     REQUIRED_ATTRIBUTES = ('instance_id', 'table_id')  # type: Iterable[str]
-    template_fields = [
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'table_id',
         'impersonation_chain',
-    ]  # type: Iterable[str]
+    )
 
     def __init__(
         self,
@@ -521,7 +524,7 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -578,13 +581,13 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
     """
 
     REQUIRED_ATTRIBUTES = ('instance_id', 'cluster_id', 'nodes')  # type: Iterable[str]
-    template_fields = [
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'cluster_id',
         'nodes',
         'impersonation_chain',
-    ]  # type: Iterable[str]
+    )
 
     def __init__(
         self,
@@ -606,7 +609,7 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
         self.impersonation_chain = impersonation_chain
         super().__init__(**kwargs)
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = BigtableHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
