@@ -19,7 +19,7 @@
 """This module contains Google Cloud Transfer operators."""
 from copy import deepcopy
 from datetime import date, time
-from typing import Dict, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Union
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -56,6 +56,9 @@ from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import
 )
 from airflow.providers.google.cloud.utils.helpers import normalize_directory_path
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class TransferJobPreprocessor:
     """Helper class for preprocess of transfer job body."""
@@ -212,7 +215,7 @@ class CloudDataTransferServiceCreateJobOperator(BaseOperator):
     """
 
     # [START gcp_transfer_job_create_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'body',
         'gcp_conn_id',
         'aws_conn_id',
@@ -241,7 +244,7 @@ class CloudDataTransferServiceCreateJobOperator(BaseOperator):
     def _validate_inputs(self) -> None:
         TransferJobValidator(body=self.body).validate_body()
 
-    def execute(self, context) -> dict:
+    def execute(self, context: 'Context') -> dict:
         TransferJobPreprocessor(body=self.body, aws_conn_id=self.aws_conn_id).process_body()
         hook = CloudDataTransferServiceHook(
             api_version=self.api_version,
@@ -290,7 +293,7 @@ class CloudDataTransferServiceUpdateJobOperator(BaseOperator):
     """
 
     # [START gcp_transfer_job_update_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'job_name',
         'body',
         'gcp_conn_id',
@@ -324,7 +327,7 @@ class CloudDataTransferServiceUpdateJobOperator(BaseOperator):
         if not self.job_name:
             raise AirflowException("The required parameter 'job_name' is empty or None")
 
-    def execute(self, context) -> dict:
+    def execute(self, context: 'Context') -> dict:
         TransferJobPreprocessor(body=self.body, aws_conn_id=self.aws_conn_id).process_body()
         hook = CloudDataTransferServiceHook(
             api_version=self.api_version,
@@ -367,7 +370,7 @@ class CloudDataTransferServiceDeleteJobOperator(BaseOperator):
     """
 
     # [START gcp_transfer_job_delete_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'job_name',
         'project_id',
         'gcp_conn_id',
@@ -398,7 +401,7 @@ class CloudDataTransferServiceDeleteJobOperator(BaseOperator):
         if not self.job_name:
             raise AirflowException("The required parameter 'job_name' is empty or None")
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         self._validate_inputs()
         hook = CloudDataTransferServiceHook(
             api_version=self.api_version,
@@ -436,7 +439,7 @@ class CloudDataTransferServiceGetOperationOperator(BaseOperator):
     """
 
     # [START gcp_transfer_operation_get_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'operation_name',
         'gcp_conn_id',
         'google_impersonation_chain',
@@ -463,7 +466,7 @@ class CloudDataTransferServiceGetOperationOperator(BaseOperator):
         if not self.operation_name:
             raise AirflowException("The required parameter 'operation_name' is empty or None")
 
-    def execute(self, context) -> dict:
+    def execute(self, context: 'Context') -> dict:
         hook = CloudDataTransferServiceHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
@@ -502,7 +505,7 @@ class CloudDataTransferServiceListOperationsOperator(BaseOperator):
     """
 
     # [START gcp_transfer_operations_list_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'filter',
         'gcp_conn_id',
         'google_impersonation_chain',
@@ -537,7 +540,7 @@ class CloudDataTransferServiceListOperationsOperator(BaseOperator):
         if not self.filter:
             raise AirflowException("The required parameter 'filter' is empty or None")
 
-    def execute(self, context) -> List[dict]:
+    def execute(self, context: 'Context') -> List[dict]:
         hook = CloudDataTransferServiceHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
@@ -574,7 +577,7 @@ class CloudDataTransferServicePauseOperationOperator(BaseOperator):
     """
 
     # [START gcp_transfer_operation_pause_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'operation_name',
         'gcp_conn_id',
         'api_version',
@@ -602,7 +605,7 @@ class CloudDataTransferServicePauseOperationOperator(BaseOperator):
         if not self.operation_name:
             raise AirflowException("The required parameter 'operation_name' is empty or None")
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = CloudDataTransferServiceHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
@@ -637,7 +640,7 @@ class CloudDataTransferServiceResumeOperationOperator(BaseOperator):
     """
 
     # [START gcp_transfer_operation_resume_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'operation_name',
         'gcp_conn_id',
         'api_version',
@@ -665,7 +668,7 @@ class CloudDataTransferServiceResumeOperationOperator(BaseOperator):
         if not self.operation_name:
             raise AirflowException("The required parameter 'operation_name' is empty or None")
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = CloudDataTransferServiceHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
@@ -701,7 +704,7 @@ class CloudDataTransferServiceCancelOperationOperator(BaseOperator):
     """
 
     # [START gcp_transfer_operation_cancel_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'operation_name',
         'gcp_conn_id',
         'api_version',
@@ -729,7 +732,7 @@ class CloudDataTransferServiceCancelOperationOperator(BaseOperator):
         if not self.operation_name:
             raise AirflowException("The required parameter 'operation_name' is empty or None")
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = CloudDataTransferServiceHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
@@ -817,7 +820,7 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
     :type delete_job_after_completion: bool
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'gcp_conn_id',
         's3_bucket',
         'gcs_bucket',
@@ -874,7 +877,7 @@ class CloudDataTransferServiceS3ToGCSOperator(BaseOperator):
         if self.delete_job_after_completion and not self.wait:
             raise AirflowException("If 'delete_job_after_completion' is True, then 'wait' must also be True.")
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = CloudDataTransferServiceHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -1003,7 +1006,7 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
     :type delete_job_after_completion: bool
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'gcp_conn_id',
         'source_bucket',
         'destination_bucket',
@@ -1058,7 +1061,7 @@ class CloudDataTransferServiceGCSToGCSOperator(BaseOperator):
         if self.delete_job_after_completion and not self.wait:
             raise AirflowException("If 'delete_job_after_completion' is True, then 'wait' must also be True.")
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = CloudDataTransferServiceHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
