@@ -18,7 +18,7 @@
 """This module contains Google Compute Engine operators."""
 
 from copy import deepcopy
-from typing import Any, Dict, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
 
 from googleapiclient.errors import HttpError
 from json_merge_patch import merge
@@ -28,13 +28,14 @@ from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.compute import ComputeEngineHook
 from airflow.providers.google.cloud.utils.field_sanitizer import GcpBodyFieldSanitizer
 from airflow.providers.google.cloud.utils.field_validator import GcpBodyFieldValidator
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class ComputeEngineBaseOperator(BaseOperator):
     """Abstract base operator for Google Compute Engine operators to inherit from."""
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -63,7 +64,7 @@ class ComputeEngineBaseOperator(BaseOperator):
         if not self.resource_id:
             raise AirflowException("The required parameter 'resource_id' is missing")
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         pass
 
 
@@ -89,8 +90,6 @@ class ComputeEngineStartInstanceOperator(ComputeEngineBaseOperator):
     :param api_version: Optional, API version used (for example v1 - or beta). Defaults
         to v1.
     :type api_version: str
-    :param validate_body: Optional, If set to False, body validation is not performed.
-        Defaults to False.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -103,7 +102,7 @@ class ComputeEngineStartInstanceOperator(ComputeEngineBaseOperator):
     """
 
     # [START gce_instance_start_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'zone',
         'resource_id',
@@ -113,29 +112,7 @@ class ComputeEngineStartInstanceOperator(ComputeEngineBaseOperator):
     )
     # [END gce_instance_start_template_fields]
 
-    @apply_defaults
-    def __init__(
-        self,
-        *,
-        zone: str,
-        resource_id: str,
-        project_id: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        api_version: str = 'v1',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
-        **kwargs,
-    ) -> None:
-        super().__init__(
-            project_id=project_id,
-            zone=zone,
-            resource_id=resource_id,
-            gcp_conn_id=gcp_conn_id,
-            api_version=api_version,
-            impersonation_chain=impersonation_chain,
-            **kwargs,
-        )
-
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
@@ -166,8 +143,6 @@ class ComputeEngineStopInstanceOperator(ComputeEngineBaseOperator):
     :param api_version: Optional, API version used (for example v1 - or beta). Defaults
         to v1.
     :type api_version: str
-    :param validate_body: Optional, If set to False, body validation is not performed.
-        Defaults to False.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -180,7 +155,7 @@ class ComputeEngineStopInstanceOperator(ComputeEngineBaseOperator):
     """
 
     # [START gce_instance_stop_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'zone',
         'resource_id',
@@ -190,29 +165,7 @@ class ComputeEngineStopInstanceOperator(ComputeEngineBaseOperator):
     )
     # [END gce_instance_stop_template_fields]
 
-    @apply_defaults
-    def __init__(
-        self,
-        *,
-        zone: str,
-        resource_id: str,
-        project_id: Optional[str] = None,
-        gcp_conn_id: str = 'google_cloud_default',
-        api_version: str = 'v1',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
-        **kwargs,
-    ) -> None:
-        super().__init__(
-            project_id=project_id,
-            zone=zone,
-            resource_id=resource_id,
-            gcp_conn_id=gcp_conn_id,
-            api_version=api_version,
-            impersonation_chain=impersonation_chain,
-            **kwargs,
-        )
-
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
@@ -267,7 +220,7 @@ class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
     """
 
     # [START gce_instance_set_machine_type_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'zone',
         'resource_id',
@@ -278,7 +231,6 @@ class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
     )
     # [END gce_instance_set_machine_type_template_fields]
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -312,7 +264,7 @@ class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
         if self._field_validator:
             self._field_validator.validate(self.body)
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
@@ -431,7 +383,7 @@ class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
     """
 
     # [START gce_instance_template_copy_operator_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'resource_id',
         'request_id',
@@ -441,7 +393,6 @@ class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
     )
     # [END gce_instance_template_copy_operator_template_fields]
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -460,8 +411,8 @@ class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
         self._field_validator = None  # Optional[GcpBodyFieldValidator]
         if 'name' not in self.body_patch:
             raise AirflowException(
-                "The body '{}' should contain at least "
-                "name for the new operator in the 'name' field".format(body_patch)
+                f"The body '{body_patch}' should contain at least name for the new operator "
+                f"in the 'name' field"
             )
         if validate_body:
             self._field_validator = GcpBodyFieldValidator(
@@ -482,7 +433,7 @@ class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
         if self._field_validator:
             self._field_validator.validate(self.body_patch)
 
-    def execute(self, context) -> dict:
+    def execute(self, context: 'Context') -> dict:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
@@ -553,9 +504,6 @@ class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseO
     :param api_version: Optional, API version used (for example v1 - or beta). Defaults
         to v1.
     :type api_version: str
-    :param validate_body: Optional, If set to False, body validation is not performed.
-        Defaults to False.
-    :type validate_body: bool
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -568,7 +516,7 @@ class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseO
     """
 
     # [START gce_igm_update_template_operator_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'resource_id',
         'zone',
@@ -581,7 +529,6 @@ class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseO
     )
     # [END gce_igm_update_template_operator_template_fields]
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -624,7 +571,7 @@ class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseO
             dictionary['instanceTemplate'] = self.destination_template
             self._change_performed = True
 
-    def execute(self, context) -> Optional[bool]:
+    def execute(self, context: 'Context') -> Optional[bool]:
         hook = ComputeEngineHook(
             gcp_conn_id=self.gcp_conn_id,
             api_version=self.api_version,
