@@ -20,7 +20,8 @@
 
 import os
 import tempfile
-from typing import Dict, Optional, Sequence, Union
+import warnings
+from typing import TYPE_CHECKING, Dict, Optional, Sequence, Union
 
 from google.cloud.container_v1.types import Cluster
 
@@ -31,6 +32,9 @@ from airflow.providers.google.cloud.hooks.kubernetes_engine import GKEHook
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 from airflow.utils.process_utils import execute_in_subprocess, patch_environ
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class GKEDeleteClusterOperator(BaseOperator):
     """
@@ -59,7 +63,7 @@ class GKEDeleteClusterOperator(BaseOperator):
     :type project_id: str
     :param name: The name of the resource to delete, in this case cluster name
     :type name: str
-    :param location: The name of the Google Compute Engine zone in which the cluster
+    :param location: The name of the Google Compute Engine zone or region in which the cluster
         resides.
     :type location: str
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
@@ -77,14 +81,14 @@ class GKEDeleteClusterOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = [
+    template_fields: Sequence[str] = (
         'project_id',
         'gcp_conn_id',
         'name',
         'location',
         'api_version',
         'impersonation_chain',
-    ]
+    )
 
     def __init__(
         self,
@@ -112,7 +116,7 @@ class GKEDeleteClusterOperator(BaseOperator):
             self.log.error('One of (project_id, name, location) is missing or incorrect')
             raise AirflowException('Operator has incorrect or missing input.')
 
-    def execute(self, context) -> Optional[str]:
+    def execute(self, context: 'Context') -> Optional[str]:
         hook = GKEHook(
             gcp_conn_id=self.gcp_conn_id,
             location=self.location,
@@ -158,7 +162,7 @@ class GKECreateClusterOperator(BaseOperator):
 
     :param project_id: The Google Developers Console [project ID or project number]
     :type project_id: str
-    :param location: The name of the Google Compute Engine zone in which the cluster
+    :param location: The name of the Google Compute Engine  or region in which the cluster
         resides.
     :type location: str
     :param body: The Cluster definition to create, can be protobuf or python dict, if
@@ -179,14 +183,14 @@ class GKECreateClusterOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = [
+    template_fields: Sequence[str] = (
         'project_id',
         'gcp_conn_id',
         'location',
         'api_version',
         'body',
         'impersonation_chain',
-    ]
+    )
 
     def __init__(
         self,
@@ -240,7 +244,7 @@ class GKECreateClusterOperator(BaseOperator):
             self.log.error("Only one of body['initial_node_count']) and body['node_pools'] may be specified")
             raise AirflowException("Operator has incorrect or missing input.")
 
-    def execute(self, context) -> str:
+    def execute(self, context: 'Context') -> str:
         hook = GKEHook(
             gcp_conn_id=self.gcp_conn_id,
             location=self.location,
@@ -273,13 +277,14 @@ class GKEStartPodOperator(KubernetesPodOperator):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:GKEStartPodOperator`
 
-    :param location: The name of the Google Kubernetes Engine zone in which the
+    :param location: The name of the Google Kubernetes Engine zone or region in which the
         cluster resides, e.g. 'us-central1-a'
     :type location: str
     :param cluster_name: The name of the Google Kubernetes Engine cluster the pod
         should be spawned in
     :type cluster_name: str
     :param use_internal_ip: Use the internal IP address as the endpoint.
+    :type use_internal_ip: bool
     :param project_id: The Google Developers Console project id
     :type project_id: str
     :param gcp_conn_id: The google cloud connection id to use. This allows for
@@ -294,9 +299,18 @@ class GKEStartPodOperator(KubernetesPodOperator):
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
     :type impersonation_chain: Union[str, Sequence[str]]
+    :param regional: The location param is region name.
+    :type regional: bool
+    :param is_delete_operator_pod: What to do when the pod reaches its final
+        state, or the execution is interrupted. If True, delete the
+        pod; if False, leave the pod.  Current default is False, but this will be
+        changed in the next major release of this provider.
+    :type is_delete_operator_pod: bool
     """
 
-    template_fields = {'project_id', 'location', 'cluster_name'} | set(KubernetesPodOperator.template_fields)
+    template_fields: Sequence[str] = tuple(
+        {'project_id', 'location', 'cluster_name'} | set(KubernetesPodOperator.template_fields)
+    )
 
     def __init__(
         self,
@@ -307,15 +321,29 @@ class GKEStartPodOperator(KubernetesPodOperator):
         project_id: Optional[str] = None,
         gcp_conn_id: str = 'google_cloud_default',
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        regional: bool = False,
+        is_delete_operator_pod: Optional[bool] = None,
         **kwargs,
     ) -> None:
-        super().__init__(**kwargs)
+        if is_delete_operator_pod is None:
+            warnings.warn(
+                f"You have not set parameter `is_delete_operator_pod` in class {self.__class__.__name__}. "
+                "Currently the default for this parameter is `False` but in a future release the default "
+                "will be changed to `True`. To ensure pods are not deleted in the future you will need to "
+                "set `is_delete_operator_pod=False` explicitly.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            is_delete_operator_pod = False
+
+        super().__init__(is_delete_operator_pod=is_delete_operator_pod, **kwargs)
         self.project_id = project_id
         self.location = location
         self.cluster_name = cluster_name
         self.gcp_conn_id = gcp_conn_id
         self.use_internal_ip = use_internal_ip
         self.impersonation_chain = impersonation_chain
+        self.regional = regional
 
         if self.gcp_conn_id is None:
             raise AirflowException(
@@ -328,7 +356,7 @@ class GKEStartPodOperator(KubernetesPodOperator):
         if self.config_file:
             raise AirflowException("config_file is not an allowed parameter for the GKEStartPodOperator.")
 
-    def execute(self, context) -> Optional[str]:
+    def execute(self, context: 'Context') -> Optional[str]:
         hook = GoogleBaseHook(gcp_conn_id=self.gcp_conn_id)
         self.project_id = self.project_id or hook.project_id
 
@@ -356,8 +384,6 @@ class GKEStartPodOperator(KubernetesPodOperator):
                 "clusters",
                 "get-credentials",
                 self.cluster_name,
-                "--zone",
-                self.location,
                 "--project",
                 self.project_id,
             ]
@@ -377,6 +403,11 @@ class GKEStartPodOperator(KubernetesPodOperator):
                         impersonation_account,
                     ]
                 )
+            if self.regional:
+                cmd.append('--region')
+            else:
+                cmd.append('--zone')
+            cmd.append(self.location)
             if self.use_internal_ip:
                 cmd.append('--internal-ip')
             execute_in_subprocess(cmd)
