@@ -16,12 +16,15 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Spanner operators."""
-from typing import List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, List, Optional, Sequence, Union
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.spanner import SpannerHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class SpannerDeployInstanceOperator(BaseOperator):
     """
@@ -62,7 +65,7 @@ class SpannerDeployInstanceOperator(BaseOperator):
     """
 
     # [START gcp_spanner_deploy_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'configuration_name',
@@ -100,7 +103,7 @@ class SpannerDeployInstanceOperator(BaseOperator):
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -148,7 +151,7 @@ class SpannerDeleteInstanceOperator(BaseOperator):
     """
 
     # [START gcp_spanner_delete_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'gcp_conn_id',
@@ -178,7 +181,7 @@ class SpannerDeleteInstanceOperator(BaseOperator):
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
 
-    def execute(self, context) -> Optional[bool]:
+    def execute(self, context: 'Context') -> Optional[bool]:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -226,7 +229,7 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
     """
 
     # [START gcp_spanner_query_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'database_id',
@@ -234,7 +237,7 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
         'gcp_conn_id',
         'impersonation_chain',
     )
-    template_ext = ('.sql',)
+    template_ext: Sequence[str] = ('.sql',)
     # [END gcp_spanner_query_template_fields]
 
     def __init__(
@@ -267,15 +270,16 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
         if not self.query:
             raise AirflowException("The required parameter 'query' is empty")
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
         )
-        queries = self.query
         if isinstance(self.query, str):
             queries = [x.strip() for x in self.query.split(';')]
             self.sanitize_queries(queries)
+        else:
+            queries = self.query
         self.log.info(
             "Executing DML query(-ies) on projects/%s/instances/%s/databases/%s",
             self.project_id,
@@ -335,7 +339,7 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
     """
 
     # [START gcp_spanner_database_deploy_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'database_id',
@@ -343,7 +347,7 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
         'gcp_conn_id',
         'impersonation_chain',
     )
-    template_ext = ('.sql',)
+    template_ext: Sequence[str] = ('.sql',)
     # [END gcp_spanner_database_deploy_template_fields]
 
     def __init__(
@@ -374,7 +378,7 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
         if not self.database_id:
             raise AirflowException("The required parameter 'database_id' is empty or None")
 
-    def execute(self, context) -> Optional[bool]:
+    def execute(self, context: 'Context') -> Optional[bool]:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -439,7 +443,7 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
     """
 
     # [START gcp_spanner_database_update_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'database_id',
@@ -447,7 +451,7 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
         'gcp_conn_id',
         'impersonation_chain',
     )
-    template_ext = ('.sql',)
+    template_ext: Sequence[str] = ('.sql',)
     # [END gcp_spanner_database_update_template_fields]
 
     def __init__(
@@ -482,7 +486,7 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
         if not self.ddl_statements:
             raise AirflowException("The required parameter 'ddl_statements' is empty or None")
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -534,7 +538,7 @@ class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
     """
 
     # [START gcp_spanner_database_delete_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'project_id',
         'instance_id',
         'database_id',
@@ -569,7 +573,7 @@ class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
         if not self.database_id:
             raise AirflowException("The required parameter 'database_id' is empty or None")
 
-    def execute(self, context) -> bool:
+    def execute(self, context: 'Context') -> bool:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
