@@ -16,7 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-from typing import Optional, Sequence, Union
+from typing import TYPE_CHECKING, Optional, Sequence, Tuple, Union
 
 from google.api_core.gapic_v1.method import DEFAULT
 from google.cloud.monitoring_v3 import AlertPolicy, NotificationChannel
@@ -24,6 +24,9 @@ from google.cloud.monitoring_v3 import AlertPolicy, NotificationChannel
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.stackdriver import StackdriverHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class StackdriverListAlertPoliciesOperator(BaseOperator):
     """
@@ -64,7 +67,7 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -85,7 +88,7 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'filter_',
         'impersonation_chain',
     )
@@ -99,8 +102,8 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
         order_by: Optional[str] = None,
         page_size: Optional[int] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -119,9 +122,9 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
         self.project_id = project_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info(
             'List Alert Policies: Project id: %s Format: %s Filter: %s Order By: %s Page Size: %s',
             self.project_id,
@@ -171,7 +174,7 @@ class StackdriverEnableAlertPoliciesOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -193,7 +196,7 @@ class StackdriverEnableAlertPoliciesOperator(BaseOperator):
     """
 
     ui_color = "#e5ffcc"
-    template_fields = (
+    template_fields: Sequence[str] = (
         'filter_',
         'impersonation_chain',
     )
@@ -203,8 +206,8 @@ class StackdriverEnableAlertPoliciesOperator(BaseOperator):
         *,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -220,9 +223,9 @@ class StackdriverEnableAlertPoliciesOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info('Enable Alert Policies: Project id: %s Filter: %s', self.project_id, self.filter_)
         if self.hook is None:
             self.hook = StackdriverHook(
@@ -261,7 +264,7 @@ class StackdriverDisableAlertPoliciesOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -283,7 +286,7 @@ class StackdriverDisableAlertPoliciesOperator(BaseOperator):
     """
 
     ui_color = "#e5ffcc"
-    template_fields = (
+    template_fields: Sequence[str] = (
         'filter_',
         'impersonation_chain',
     )
@@ -293,8 +296,8 @@ class StackdriverDisableAlertPoliciesOperator(BaseOperator):
         *,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -310,9 +313,9 @@ class StackdriverDisableAlertPoliciesOperator(BaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info('Disable Alert Policies: Project id: %s Filter: %s', self.project_id, self.filter_)
         if self.hook is None:
             self.hook = StackdriverHook(
@@ -351,7 +354,7 @@ class StackdriverUpsertAlertOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -372,11 +375,11 @@ class StackdriverUpsertAlertOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'alerts',
         'impersonation_chain',
     )
-    template_ext = ('.json',)
+    template_ext: Sequence[str] = ('.json',)
 
     ui_color = "#e5ffcc"
 
@@ -385,8 +388,8 @@ class StackdriverUpsertAlertOperator(BaseOperator):
         *,
         alerts: str,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -402,9 +405,9 @@ class StackdriverUpsertAlertOperator(BaseOperator):
         self.project_id = project_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info('Upsert Alert Policies: Alerts: %s Project id: %s', self.alerts, self.project_id)
         if self.hook is None:
             self.hook = StackdriverHook(
@@ -440,7 +443,7 @@ class StackdriverDeleteAlertOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -461,7 +464,7 @@ class StackdriverDeleteAlertOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'name',
         'impersonation_chain',
     )
@@ -473,8 +476,8 @@ class StackdriverDeleteAlertOperator(BaseOperator):
         *,
         name: str,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -490,9 +493,9 @@ class StackdriverDeleteAlertOperator(BaseOperator):
         self.project_id = project_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info('Delete Alert Policy: Project id: %s Name: %s', self.project_id, self.name)
         if self.hook is None:
             self.hook = StackdriverHook(
@@ -547,7 +550,7 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -568,7 +571,7 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'filter_',
         'impersonation_chain',
     )
@@ -583,8 +586,8 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
         order_by: Optional[str] = None,
         page_size: Optional[int] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -603,9 +606,9 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
         self.project_id = project_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info(
             'List Notification Channels: Project id: %s Format: %s Filter: %s Order By: %s Page Size: %s',
             self.project_id,
@@ -655,7 +658,7 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -676,7 +679,7 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'filter_',
         'impersonation_chain',
     )
@@ -688,8 +691,8 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
         *,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -705,9 +708,9 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
         self.project_id = project_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info(
             'Enable Notification Channels: Project id: %s Filter: %s', self.project_id, self.filter_
         )
@@ -747,7 +750,7 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -768,7 +771,7 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'filter_',
         'impersonation_chain',
     )
@@ -780,8 +783,8 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
         *,
         filter_: Optional[str] = None,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -797,9 +800,9 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
         self.project_id = project_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info(
             'Disable Notification Channels: Project id: %s Filter: %s', self.project_id, self.filter_
         )
@@ -840,7 +843,7 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -861,11 +864,11 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'channels',
         'impersonation_chain',
     )
-    template_ext = ('.json',)
+    template_ext: Sequence[str] = ('.json',)
 
     ui_color = "#e5ffcc"
 
@@ -874,8 +877,8 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
         *,
         channels: str,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[str] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -891,9 +894,9 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
         self.project_id = project_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info(
             'Upsert Notification Channels: Channels: %s Project id: %s', self.channels, self.project_id
         )
@@ -931,7 +934,7 @@ class StackdriverDeleteNotificationChannelOperator(BaseOperator):
         specified, the timeout applies to each individual attempt.
     :type timeout: float
     :param metadata: Additional metadata that is provided to the method.
-    :type metadata: str
+    :type metadata: Sequence[Tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :type gcp_conn_id: str
@@ -952,7 +955,7 @@ class StackdriverDeleteNotificationChannelOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'name',
         'impersonation_chain',
     )
@@ -964,8 +967,8 @@ class StackdriverDeleteNotificationChannelOperator(BaseOperator):
         *,
         name: str,
         retry: Optional[str] = DEFAULT,
-        timeout: Optional[float] = DEFAULT,
-        metadata: Optional[str] = None,
+        timeout: Optional[float] = None,
+        metadata: Sequence[Tuple[str, str]] = (),
         gcp_conn_id: str = 'google_cloud_default',
         project_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
@@ -981,9 +984,9 @@ class StackdriverDeleteNotificationChannelOperator(BaseOperator):
         self.project_id = project_id
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
-        self.hook = None
+        self.hook: Optional[StackdriverHook] = None
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info('Delete Notification Channel: Project id: %s Name: %s', self.project_id, self.name)
         if self.hook is None:
             self.hook = StackdriverHook(
