@@ -16,7 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Translate Speech operator."""
-from typing import Optional, Sequence, Union
+from typing import TYPE_CHECKING, Optional, Sequence, Union
 
 from google.cloud.speech_v1.types import RecognitionAudio, RecognitionConfig
 from google.protobuf.json_format import MessageToDict
@@ -26,6 +26,9 @@ from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.speech_to_text import CloudSpeechToTextHook
 from airflow.providers.google.cloud.hooks.translate import CloudTranslateHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class CloudTranslateSpeechOperator(BaseOperator):
     """
@@ -106,7 +109,7 @@ class CloudTranslateSpeechOperator(BaseOperator):
     """
 
     # [START translate_speech_template_fields]
-    template_fields = (
+    template_fields: Sequence[str] = (
         'target_language',
         'format_',
         'source_language',
@@ -142,7 +145,7 @@ class CloudTranslateSpeechOperator(BaseOperator):
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context) -> dict:
+    def execute(self, context: 'Context') -> dict:
         speech_to_text_hook = CloudSpeechToTextHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
