@@ -16,7 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Dataflow sensor."""
-from typing import Callable, Optional, Sequence, Set, Union
+from typing import TYPE_CHECKING, Callable, Optional, Sequence, Set, Union
 
 from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.dataflow import (
@@ -25,7 +25,9 @@ from airflow.providers.google.cloud.hooks.dataflow import (
     DataflowJobStatus,
 )
 from airflow.sensors.base import BaseSensorOperator
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class DataflowJobStatusSensor(BaseSensorOperator):
@@ -66,9 +68,8 @@ class DataflowJobStatusSensor(BaseSensorOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = ['job_id']
+    template_fields: Sequence[str] = ('job_id',)
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -93,7 +94,7 @@ class DataflowJobStatusSensor(BaseSensorOperator):
         self.impersonation_chain = impersonation_chain
         self.hook: Optional[DataflowHook] = None
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: 'Context') -> bool:
         self.log.info(
             "Waiting for job %s to be in one of the states: %s.",
             self.job_id,
@@ -161,9 +162,8 @@ class DataflowJobMetricsSensor(BaseSensorOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = ['job_id']
+    template_fields: Sequence[str] = ('job_id',)
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -188,7 +188,7 @@ class DataflowJobMetricsSensor(BaseSensorOperator):
         self.impersonation_chain = impersonation_chain
         self.hook: Optional[DataflowHook] = None
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: 'Context') -> bool:
         self.hook = DataflowHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -255,9 +255,8 @@ class DataflowJobMessagesSensor(BaseSensorOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = ['job_id']
+    template_fields: Sequence[str] = ('job_id',)
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -282,7 +281,7 @@ class DataflowJobMessagesSensor(BaseSensorOperator):
         self.impersonation_chain = impersonation_chain
         self.hook: Optional[DataflowHook] = None
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: 'Context') -> bool:
         self.hook = DataflowHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -349,9 +348,8 @@ class DataflowJobAutoScalingEventsSensor(BaseSensorOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = ['job_id']
+    template_fields: Sequence[str] = ('job_id',)
 
-    @apply_defaults
     def __init__(
         self,
         *,
@@ -376,7 +374,7 @@ class DataflowJobAutoScalingEventsSensor(BaseSensorOperator):
         self.impersonation_chain = impersonation_chain
         self.hook: Optional[DataflowHook] = None
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: 'Context') -> bool:
         self.hook = DataflowHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
