@@ -18,14 +18,17 @@
 """This module contains Google Cloud Storage sensors."""
 
 import os
+import textwrap
 import warnings
 from datetime import datetime
-from typing import Callable, List, Optional, Sequence, Set, Union
+from typing import TYPE_CHECKING, Callable, List, Optional, Sequence, Set, Union
 
 from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
 from airflow.sensors.base import BaseSensorOperator, poke_mode_only
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class GCSObjectExistenceSensor(BaseSensorOperator):
@@ -55,19 +58,18 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'bucket',
         'object',
         'impersonation_chain',
     )
     ui_color = '#f0eee4'
 
-    @apply_defaults
     def __init__(
         self,
         *,
         bucket: str,
-        object: str,  # pylint: disable=redefined-builtin
+        object: str,
         google_cloud_conn_id: str = 'google_cloud_default',
         delegate_to: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
@@ -81,7 +83,7 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: "Context") -> bool:
         self.log.info('Sensor checks existence of : %s, %s', self.bucket, self.object)
         hook = GCSHook(
             gcp_conn_id=self.google_cloud_conn_id,
@@ -94,10 +96,14 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
 def ts_function(context):
     """
     Default callback for the GoogleCloudStorageObjectUpdatedSensor. The default
-    behaviour is check for the object being updated after execution_date +
-    schedule_interval.
+    behaviour is check for the object being updated after the data interval's
+    end, or execution_date + interval on Airflow versions prior to 2.2 (before
+    AIP-39 implementation).
     """
-    return context['dag'].following_schedule(context['execution_date'])
+    try:
+        return context["data_interval_end"]
+    except KeyError:
+        return context["dag"].following_schedule(context["execution_date"])
 
 
 class GCSObjectUpdateSensor(BaseSensorOperator):
@@ -131,18 +137,17 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'bucket',
         'object',
         'impersonation_chain',
     )
     ui_color = '#f0eee4'
 
-    @apply_defaults
     def __init__(
         self,
         bucket: str,
-        object: str,  # pylint: disable=redefined-builtin
+        object: str,
         ts_func: Callable = ts_function,
         google_cloud_conn_id: str = 'google_cloud_default',
         delegate_to: Optional[str] = None,
@@ -158,7 +163,7 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: "Context") -> bool:
         self.log.info('Sensor checks existence of : %s, %s', self.bucket, self.object)
         hook = GCSHook(
             gcp_conn_id=self.google_cloud_conn_id,
@@ -199,14 +204,13 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'bucket',
         'prefix',
         'impersonation_chain',
     )
     ui_color = '#f0eee4'
 
-    @apply_defaults
     def __init__(
         self,
         bucket: str,
@@ -224,7 +228,7 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
         self._matches: List[str] = []
         self.impersonation_chain = impersonation_chain
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: "Context") -> bool:
         self.log.info('Sensor checks existence of objects: %s, %s', self.bucket, self.prefix)
         hook = GCSHook(
             gcp_conn_id=self.google_cloud_conn_id,
@@ -234,7 +238,7 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
         self._matches = hook.list(self.bucket, prefix=self.prefix)
         return bool(self._matches)
 
-    def execute(self, context: dict) -> List[str]:
+    def execute(self, context: "Context") -> List[str]:
         """Overridden to allow matches to be passed"""
         super().execute(context)
         return self._matches
@@ -310,14 +314,13 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'bucket',
         'prefix',
         'impersonation_chain',
     )
     ui_color = '#f0eee4'
 
-    @apply_defaults
     def __init__(
         self,
         bucket: str,
@@ -386,22 +389,21 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
                 self.previous_objects = current_objects
                 self.last_activity_time = get_time()
                 self.log.warning(
-                    """
+                    textwrap.dedent(
+                        """\
                     Objects were deleted during the last
                     poke interval. Updating the file counter and
                     resetting last_activity_time.
-                    %s
-                    """,
+                    %s\
+                    """
+                    ),
                     self.previous_objects - current_objects,
                 )
                 return False
 
             raise AirflowException(
-                """
-                Illegal behavior: objects were deleted in {} between pokes.
-                """.format(
-                    os.path.join(self.bucket, self.prefix)
-                )
+                "Illegal behavior: objects were deleted in "
+                f"{os.path.join(self.bucket, self.prefix)} between pokes."
             )
 
         if self.last_activity_time:
@@ -416,10 +418,13 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
 
             if current_num_objects >= self.min_objects:
                 self.log.info(
-                    """SUCCESS:
-                    Sensor found %s objects at %s.
-                    Waited at least %s seconds, with no new objects dropped.
-                    """,
+                    textwrap.dedent(
+                        """\
+                        SUCCESS:
+                        Sensor found %s objects at %s.
+                        Waited at least %s seconds, with no new objects dropped.
+                        """
+                    ),
                     current_num_objects,
                     path,
                     self.inactivity_period,
@@ -431,7 +436,7 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
             return False
         return False
 
-    def poke(self, context: dict) -> bool:
+    def poke(self, context: "Context") -> bool:
         return self.is_bucket_updated(
             set(self._get_gcs_hook().list(self.bucket, prefix=self.prefix))  # type: ignore[union-attr]
         )
