@@ -17,11 +17,13 @@
 # under the License.
 """This module contains Google BigQuery to BigQuery operator."""
 import warnings
-from typing import Dict, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Union
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigquery import BigQueryHook
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class BigQueryToBigQueryOperator(BaseOperator):
@@ -77,19 +79,18 @@ class BigQueryToBigQueryOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'source_project_dataset_tables',
         'destination_project_dataset_table',
         'labels',
         'impersonation_chain',
     )
-    template_ext = ('.sql',)
+    template_ext: Sequence[str] = ('.sql',)
     ui_color = '#e6f0e4'
 
-    @apply_defaults
     def __init__(
         self,
-        *,  # pylint: disable=too-many-arguments
+        *,
         source_project_dataset_tables: Union[List[str], str],
         destination_project_dataset_table: str,
         write_disposition: str = 'WRITE_EMPTY',
@@ -125,7 +126,7 @@ class BigQueryToBigQueryOperator(BaseOperator):
         self.location = location
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context) -> None:
+    def execute(self, context: 'Context') -> None:
         self.log.info(
             'Executing copy of %s into: %s',
             self.source_project_dataset_tables,
