@@ -17,7 +17,7 @@
 # under the License.
 """This module contains a Google Cloud Storage operator."""
 import warnings
-from typing import Optional, Sequence, Union
+from typing import TYPE_CHECKING, Optional, Sequence, Union
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -25,6 +25,9 @@ from airflow.providers.google.cloud.hooks.gcs import GCSHook
 
 WILDCARD = '*'
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class GCSToGCSOperator(BaseOperator):
     """
@@ -173,7 +176,7 @@ class GCSToGCSOperator(BaseOperator):
 
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'source_bucket',
         'source_object',
         'source_objects',
@@ -229,7 +232,7 @@ class GCSToGCSOperator(BaseOperator):
         self.is_older_than = is_older_than
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
 
         hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
