@@ -18,13 +18,17 @@
 """This module contains SFTP to Google Cloud Storage operator."""
 import os
 from tempfile import NamedTemporaryFile
-from typing import Optional, Sequence, Union
+from typing import TYPE_CHECKING, Optional, Sequence, Union
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
 from airflow.providers.sftp.hooks.sftp import SFTPHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
+
 WILDCARD = "*"
 
 
@@ -78,7 +82,7 @@ class SFTPToGCSOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         "source_path",
         "destination_path",
         "destination_bucket",
@@ -113,7 +117,7 @@ class SFTPToGCSOperator(BaseOperator):
         self.move_object = move_object
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         gcs_hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -168,6 +172,7 @@ class SFTPToGCSOperator(BaseOperator):
                 object_name=destination_object,
                 filename=tmp.name,
                 mime_type=self.mime_type,
+                gzip=self.gzip,
             )
 
         if self.move_object:
