@@ -20,7 +20,7 @@ import abc
 import json
 import warnings
 from tempfile import NamedTemporaryFile
-from typing import Optional, Sequence, Union
+from typing import TYPE_CHECKING, Dict, Optional, Sequence, Union
 
 import pyarrow as pa
 import pyarrow.parquet as pq
@@ -28,11 +28,15 @@ import unicodecsv as csv
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
 class BaseSQLToGCSOperator(BaseOperator):
     """
+    Copy data from SQL to Google Cloud Storage in JSON or CSV format.
+
     :param sql: The SQL to execute.
     :type sql: str
     :param bucket: The bucket to upload to.
@@ -87,7 +91,7 @@ class BaseSQLToGCSOperator(BaseOperator):
     :type impersonation_chain: Union[str, Sequence[str]]
     """
 
-    template_fields = (
+    template_fields: Sequence[str] = (
         'sql',
         'bucket',
         'filename',
@@ -96,13 +100,12 @@ class BaseSQLToGCSOperator(BaseOperator):
         'parameters',
         'impersonation_chain',
     )
-    template_ext = ('.sql',)
+    template_ext: Sequence[str] = ('.sql',)
     ui_color = '#a0e08c'
 
-    @apply_defaults
     def __init__(
         self,
-        *,  # pylint: disable=too-many-arguments
+        *,
         sql: str,
         bucket: str,
         filename: str,
@@ -146,7 +149,7 @@ class BaseSQLToGCSOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context):
+    def execute(self, context: 'Context'):
         self.log.info("Executing query")
         cursor = self.query()
 
@@ -184,6 +187,7 @@ class BaseSQLToGCSOperator(BaseOperator):
         schema = list(map(lambda schema_tuple: schema_tuple[0], cursor.description))
         col_type_dict = self._get_col_type_dict()
         file_no = 0
+
         tmp_file_handle = NamedTemporaryFile(delete=True)
         if self.export_format == 'csv':
             file_mime_type = 'text/csv'
@@ -234,6 +238,7 @@ class BaseSQLToGCSOperator(BaseOperator):
             # Stop if the file exceeds the file size limit.
             if tmp_file_handle.tell() >= self.approx_max_file_size_bytes:
                 file_no += 1
+
                 tmp_file_handle = NamedTemporaryFile(delete=True)
                 files_to_upload.append(
                     {
@@ -276,7 +281,8 @@ class BaseSQLToGCSOperator(BaseOperator):
         }
 
         columns = [field[0] for field in cursor.description]
-        bq_types = [self.field_to_bigquery(field) for field in cursor.description]
+        bq_fields = [self.field_to_bigquery(field) for field in cursor.description]
+        bq_types = [bq_field.get('type') if bq_field is not None else None for bq_field in bq_fields]
         pq_types = [type_map.get(bq_type, pa.string()) for bq_type in bq_types]
         parquet_schema = pa.schema(zip(columns, pq_types))
         return parquet_schema
@@ -286,7 +292,7 @@ class BaseSQLToGCSOperator(BaseOperator):
         """Execute DBAPI query."""
 
     @abc.abstractmethod
-    def field_to_bigquery(self, field):
+    def field_to_bigquery(self, field) -> Dict[str, str]:
         """Convert a DBAPI field to BigQuery schema format."""
 
     @abc.abstractmethod
